<a id="top"></a>
# Commercial users of Catch

As well as [Open Source](opensource-users.md#top) users Catch is widely used within proprietary code bases too.
Many organisations like to keep this information internal, and that's fine, 
but if you're more open it would be great if we could list the names of as
many organisations as possible that use Catch somewhere in their codebase. 
Enterprise environments often tend to be far more conservative in their tool adoption - 
and being aware that other companies are using Catch can ease the path in.

So if you are aware of Catch usage in your organisation, and are fairly confident there is no issue with sharing this
fact then please let us know - either directly, via a PR or 
[issue](https://github.com/philsquared/Catch/issues), or on the [forums](https://groups.google.com/forum/?fromgroups#!forum/catch-forum).
 
 - Bloomberg
 - [Bloomlife](https://bloomlife.com)
 - NASA
 - [Inscopix Inc.](https://www.inscopix.com/)
 - [Makimo](https://makimo.pl/)
 - [UX3D](https://ux3d.io)
 - [King](https://king.com)
 
